@@ -1,14 +1,11 @@
 ##----------------------------------------------------------------------------
 ## Stripe API - ~/lib/Net/API/Stripe/Connect/Person.pm
-## Version 0.1
+## Version v0.200.0
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <jack@deguest.jp>
+## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
 ## Created 2019/11/02
-## Modified 2020/03/29
-## All rights reserved
+## Modified 2020/05/15
 ## 
-## This program is free software; you can redistribute  it  and/or  modify  it
-## under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
 package Net::API::Stripe::Connect::Person;
 BEGIN
@@ -18,7 +15,7 @@ BEGIN
 	use DateTime;
 	use DateTime::Format::Strptime;
 	use TryCatch;
-	our( $VERSION ) = '0.2';
+	our( $VERSION ) = 'v0.200.0';
 };
 
 sub id { return( shift->_set_get_scalar( 'id', @_ ) ); }
@@ -149,7 +146,7 @@ See documentation in L<Net::API::Stripe> for example to make api calls to Stripe
 
 =head1 VERSION
 
-    0.2
+    v0.200.0
 
 =head1 DESCRIPTION
 
