@@ -1,21 +1,18 @@
 ##----------------------------------------------------------------------------
 ## Stripe API - ~/lib/Net/API/Stripe/Shipping.pm
-## Version 0.1
+## Version v0.1.1
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <jack@deguest.jp>
+## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
 ## Created 2019/11/02
-## Modified 2020/03/29
-## All rights reserved
+## Modified 2020/05/15
 ## 
-## This program is free software; you can redistribute  it  and/or  modify  it
-## under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
 package Net::API::Stripe::Shipping;
 BEGIN
 {
     use strict;
     use parent qw( Net::API::Stripe::Generic );
-    our( $VERSION ) = '0.1.1';
+    our( $VERSION ) = 'v0.1.1';
 };
 
 sub address { return( shift->_set_get_object( 'address', 'Net::API::Stripe::Address', @_ ) ); }
@@ -65,7 +62,7 @@ Net::API::Stripe::Shipping - A Stripe Shipping Object
 
 =head1 VERSION
 
-    0.1.1
+    v0.1.1
 
 =head1 DESCRIPTION
 
